summaryrefslogtreecommitdiffstats
path: root/kbabel/kbabel/kbabel.h
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/kbabel/kbabel.h')
-rw-r--r--kbabel/kbabel/kbabel.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/kbabel/kbabel/kbabel.h b/kbabel/kbabel/kbabel.h
index 10f57336..392f71ad 100644
--- a/kbabel/kbabel/kbabel.h
+++ b/kbabel/kbabel/kbabel.h
@@ -22,11 +22,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -82,6 +82,7 @@ namespace KBabel
class KBabelMW : public KDockMainWindow
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Default Constructor
@@ -111,20 +112,20 @@ public:
* @return A pointer to a KBabel, that has opened file URL or 0 if no
* KBabel was found
*/
- static KBabelMW *winForURL(const KURL& url, TQString projectFile = TQString::null);
+ static KBabelMW *winForURL(const KURL& url, TQString projectFile = TQString());
/**
* @return A pointer to a KBabel, that has opened no file URL or 0 if no
* KBabel was found
*/
- static KBabelMW *emptyWin(TQString projectFile = TQString::null);
+ static KBabelMW *emptyWin(TQString projectFile = TQString());
public slots:
void toggleEditMode();
protected:
/**
* Overridden virtuals for Qt drag 'n drop (XDND)
*/
virtual void dragEnterEvent(TQDragEnterEvent *event);
virtual void dropEvent(TQDropEvent *event);
@@ -111,20 +112,20 @@ public:
protected:
/**
- * Overridden virtuals for Qt drag 'n drop (XDND)
+ * Overridden virtuals for TQt drag 'n drop (XDND)
*/
virtual void dragEnterEvent(TQDragEnterEvent *event);